#! /bin/sh
#
# Note that we have to convert cases of double quotes in the
# amigaguide @{...} output, and also in @node lines, to single
# quotes, since it confuses amigaguide and there doesn't seem to
# be any way to escape them.

tmpd=`date +%j%H%M%S`
tmp1="/tmp/sh1-$tmpd"
tmp2="/tmp/sh2-$tmpd"
tmp3="/tmp/sh3-$tmpd"
tmp4="/tmp/sh4-$tmpd"

volname=`pwd | sed -e 's%^/%%' -e 's%/.*%%'`

# Extract the .aminet-dir fields from each Product-Info file, sort them
# uniq them, and generate a list of categories that covers all the 
# product info files.

pitool -b -F "%A\n" -f - - <$1 | sed "s:/.*::" | sort -f | uniq >$tmp2

# Build the root node.

cat << EOF
@database Contents
@author "Amiga Library Services"
@(c) "Copyright  1995 Amiga Library Services"
@index MAIN

@node MAIN "Contents of entire GoldFish CD, sorted by category"

Material on GoldFish is classified into categories such as demos, games,
music, pictures, etc.  Click on one of the category names below to access
material in that classification:


EOF

# Generate a list of categories.

for i in `cat $tmp2`
do
	desc=`grep "^$i" <Categories | sed "s:^$i[ 	]*::"`
	printf "  @{\" %-4s \" link $i-INDEX}  $desc\n" $i
done

# Finish off the root node.

cat <<EOF


Click @{"here" system "run >nil: execute GoldFish-Vol3:Tools/scripts/SearchAPI GoldFish-Vol3:All.api"} to search all the product info files on this CD for a simple
string (case independent) or @{"regular expression" link GoldFish-Vol3:README.guide/REGEXP} and access all material
found.  Please be patient since this may take from 10 seconds to 3 minutes
depending upon your hardware configuration.  Future releases will greatly
reduce this time.
@endnode
EOF


### Now build a node for each of the subdirectories.

for i in `cat $tmp2`
do
cat <<EOF
@node $i-INDEX "Index of subdirectory: $i"

To run a program, view a picture, etc click on the name field.
For information about other versions click on the version field.
For additional information click on the description field.
If an entry occurs more than once, it simply means that there is
more than one location on this CD where the material can be found.

Click @{"here" system "run >nil: execute GoldFish-Vol3:Tools/scripts/SearchAPI GoldFish-Vol3:All.api"} to search all the product info files on this CD for a simple
string (case independent) or @{"regular expression" link GoldFish-Vol3:README.guide/REGEXP} and access all material
found.  Please be patient since this may take from 10 seconds to 3 minutes
depending upon your hardware configuration.  Future releases will greatly
reduce this time.


EOF

	# Generate a list of product info files with this particular aminet-dir field.

	pitool <$1 -b -F "@%A@%i\n" -f - - | grep "@$i/.*@" | sed "s:@.*@::" >$tmp3

	# Sort the list by the name field.

	pitool <$tmp3 -b -F "@%N@%i\n" -f - - | sort -f | sed -e "s:@.*@::" >$tmp4

	# Generate the amigaguide entry for each product in this name sorted list.

	pitool <$tmp4 -b -F "@{\" %-18.18N \" system \"run >nil: $volname:Tools/c/RunDotExecute %i\"}@{\" %8.8V \" link Find-Other-Versions}@{\" %-40.40S \" system \"run >nil: execute $volname:Tools/scripts/ViewDesc %i\"}\n" -f - -

	# Finish off the node for this subcategory.

	echo "@endnode"
done

### Build a dummy Find-Other-Versions node for now.

echo "@node Find-Other-Versions"
echo "The feature to locate information about other versions is currently unimplemented."
echo "@endnode"

### All done, clean up.

rm -f $tmp1 $tmp2 $tmp3 $tmp4
